@@ -28,7 +28,7 @@ Bahr <- function(X1, X2, n.perm = 0, just.statistic = n.perm <= 0, sim = "ordina
 ##                                                                            ##
 ################################################################################
 BF <- function(X1, X2, n.perm = 0, just.statistic = n.perm <= 0, 
-               kernel = "phiLog", sim = "ordinary", maxM = 2^14, K = 160, 
+               kernel = "phiFracA", sim = "ordinary", maxM = 2^14, K = 160, 
                seed = NULL) {
   dname <- c(deparse1(substitute(X1)), deparse1(substitute(X2)))
   cramerWrapper(X1, X2, dname = dname, n.perm = n.perm, just.statistic = just.statistic, 
