@@ -2,14 +2,16 @@
 ##                         Chen, Chen and Su (2016)                           ##
 ##                                                                            ##
 ################################################################################
-CCS <- function(X1, X2, dist.fun = stats::dist, graph.fun = MST, 
+CCS <- function(X1, X2, dist.fun = stats::dist, graph.fun = MST5, 
                 n.perm = 0, dist.args = NULL, graph.args = NULL, seed = NULL) {
+  dname <- c(deparse1(substitute(X1)), deparse1(substitute(X2)))
   gTestWrapper(X1, X2, dist.fun, graph.fun, n.perm, dist.args, graph.args, 
-               type = "weighted", seed = seed)
+               type = "weighted", seed = seed, dname = dname)
 }
 
-CCS_cat <- function(X1, X2, dist.fun, agg.type, graph.type = "mstree",
-                    K = 1, n.perm = 0, seed = NULL) {
+CCS_cat <- function(X1, X2, dist.fun, agg.type = "u", graph.type = "mstree",
+                    K = 5, n.perm = 0, seed = NULL) {
+  dname <- c(deparse1(substitute(X1)), deparse1(substitute(X2)))
   gTestWrapperCat(X1, X2, dist.fun, agg.type, graph.type, K, n.perm, 
-                  type = "weighted", seed = seed)
+                  type = "weighted", seed = seed, dname = dname)
 }
\ No newline at end of file
