@@ -4,7 +4,7 @@
 ################################################################################
 GGRL <- function(X1, X2, target1 = "y", target2 = "y", n.perm = 0, m = 1, 
                  diff.fun = f.a, agg.fun = sum, 
-                 tune = TRUE, k = 5, n.eval = 100, seed = NULL, ...) {
+                 tune = FALSE, k = 5, n.eval = 100, seed = NULL, ...) {
   if(!is.null(seed)) {
     set.seed(seed)
   }
