@@ -10,6 +10,10 @@ MST <- function(dists, K = 1) {
   ade4::mstree(dists, K)
 }
 
+MST5 <- function(dists) {
+  MST(dists, K = 5)
+}
+
 getEdgeMat <- function(pooled.mat, dist.fun, graph.fun, dist.args, graph.args) {
   dists <- do.call(dist.fun, c(list(pooled.mat), dist.args))
   E <- do.call(graph.fun, c(list(dists), graph.args))
@@ -102,7 +106,7 @@ prettyResultgTestCat <- function(res, agg.type, n.perm, type, dname) {
 
 gTestWrapper <- function(X1, X2, dist.fun = stats::dist, graph.fun = MST, 
                          n.perm = 0, dist.args = NULL, graph.args = NULL, type,
-                         seed = NULL, ...) {
+                         seed = NULL, dname = NULL, ...) {
   if(!requireNamespace("gTests", quietly = TRUE)) {
     stop("Package \"gTests\" required for using method CCS(), CF(), FR(), and ZC().")
   }
@@ -119,7 +123,9 @@ gTestWrapper <- function(X1, X2, dist.fun = stats::dist, graph.fun = MST,
   if(ncol(X1) != ncol(X2)) {
     stop("All datasets must have the same number of variables.")
   }
-  dname <- c(deparse1(substitute(X1)), deparse1(substitute(X2)))
+  if(is.null(dname)) {
+    dname <- c(deparse1(substitute(X1)), deparse1(substitute(X2)))
+  }
   colnames(X1) <- colnames(X2) <- paste0("X", 1:ncol(X1))
   E <- getEdgeMat(rbind(X1, X2), dist.fun, graph.fun, dist.args, graph.args)
   res <- gTests::g.tests(E, sample1ID = 1:nrow(X1), perm = n.perm,
@@ -130,7 +136,7 @@ gTestWrapper <- function(X1, X2, dist.fun = stats::dist, graph.fun = MST,
 }
 
 gTestWrapperCat <- function(X1, X2, dist.fun, agg.type, graph.type = "mstree", 
-                            K = 1, n.perm = 0, type, seed = NULL, ...) {
+                            K = 1, n.perm = 0, type, seed = NULL, dname = NULL, ...) {
   if(!requireNamespace("gTests", quietly = TRUE)) {
     stop("Package \"gTests\" required for using method CCS(), CF(), FR(), and ZC().")
   }
@@ -147,7 +153,9 @@ gTestWrapperCat <- function(X1, X2, dist.fun, agg.type, graph.type = "mstree",
   if(ncol(X1) != ncol(X2)) {
     stop("All datasets must have the same number of variables.")
   }
-  dname <- c(deparse1(substitute(X1)), deparse1(substitute(X2)))
+  if(is.null(dname)) {
+    dname <- c(deparse1(substitute(X1)), deparse1(substitute(X2)))
+  }
   E <- getEdgeMatCat(X1, X2, dist.fun, graph.type, K)
   res <- gTests::g.tests_discrete(E$E, E$counts, test.type = type, perm = n.perm, ...)
   res <- prettyResultgTestCat(res, agg.type, n.perm, type, dname)
